# Generated by Django 3.0.5 on 2024-02-01 20:25

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AppsToVerifyModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=400)),
                ('db_external_name', models.CharField(blank=True, max_length=400, null=True)),
                ('should_verify', models.BooleanField(default=True)),
            ],
        ),
        migrations.CreateModel(
            name='RedirectEmail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.CharField(max_length=400)),
            ],
        ),
        migrations.CreateModel(
            name='Verified',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data', models.TextField(blank=True, null=True)),
                ('started_at', models.DateTimeField(auto_now_add=True)),
                ('finished_at', models.DateTimeField(auto_now=True)),
            ],
        ),
    ]



import inspect
import importlib
from django.db.models import Count
from alegriadb import models as alegria_models

class AlegriaVerifier():

    def __init__(self,queryset):

        task = alegria_models.Verified.objects.create()
        apps_to_verify = {app.name:app.db_external_name for app in queryset}
        classes=dict()

        for app in apps_to_verify.keys():
            models = importlib.import_module(f'{app}.models')

            for model in inspect.getmembers(models, inspect.isclass):
                if '_meta' in model[1].__dict__.keys():
                    classes[model[0]]={
                        'app': app,
                        'nome':model[0],
                        'model':model[1],
                        'table_type': 'interna' if model[1]._meta.managed else 'externa',
                        'db_table': model[1]._meta.db_table,
                    }

            for model in classes.keys():
                try:
                    if classes[model]['model']._meta.managed:
                        query = classes[model]['model'].objects.all()
                    else:
                        query = classes[model]['model'].objects.using(apps_to_verify[app]).all()

                    query.first()
                    classes[model]['status'] = dict(status='ok',erro='')

                    if len(query.values('id').annotate(id_count=Count('id')).filter(id_count__gt=1))!=0:
                        classes[model]['status'] = dict(status='error',erro='dados_duplicados')

                except Exception as e:
                    classes[model]['status'] = dict(status='error',erro=e)
        task.data = classes
        task.save()
        
        print('Alegria!')


from django.db import models

class AppsToVerifyModel(models.Model):
    name = models.CharField(max_length=400)
    db_external_name = models.CharField(max_length=400, blank=True, null=True)
    should_verify = models.BooleanField(default=True)

    def __str__(self):
        return f'{self.name}'


class RedirectEmail(models.Model):
    email = models.CharField(max_length=400)

    def __str__(self):
        return f'{self.email}'


class Verified(models.Model):
    data = models.TextField(blank=True, null=True)
    started_at = models.DateTimeField(auto_now_add=True)
    finished_at = models.DateTimeField(auto_now=True)
    